@@ -1,9 +1,9 @@
 /*
  * fonts.c
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -39,7 +39,7 @@
 #include "fonts/font_amiga_topaz_500_plus.h"
 
 void
-alSelectFont(struct fontStruct *fontData, int font)
+select_font(struct fontStruct *fontData, int font)
 {
 	switch (font) {
 	case ANSILOVE_FONT_CP437_80x50:
