@@ -1,9 +1,9 @@
 /*
  * fonts.h
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -23,7 +23,7 @@ struct fontStruct {
 	bool isAmigaFont;
 };
 
-void alSelectFont(struct fontStruct *fontData, int font);
+void select_font(struct fontStruct *, int);
 
 extern const uint8_t font_pc_80x25[4096];
 extern const uint8_t font_pc_80x50[2048];
