@@ -1,9 +1,9 @@
 /*
  * ansi.c
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -72,7 +72,8 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	const char *errstr;
 
 	/* font selection */
-	alSelectFont(&fontData, options->font);
+	memset(&fontData, 0, sizeof(struct fontStruct));
+	select_font(&fontData, options->font);
 
 	switch (options->mode) {
 	case ANSILOVE_MODE_CED:
@@ -96,6 +97,7 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 
 	/* default color values */
 	uint32_t background = 0, foreground = 7;
+	uint32_t background24 = 0, foreground24 = 0;
 
 	/* text attributes */
 	bool bold = false, blink = false, invert = false;
@@ -300,7 +302,9 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 
 							if (seqValue == 0) {
 								background = 0;
+								background24 = 0;
 								foreground = 7;
+								foreground24 = 0;
 								bold = false;
 								blink = false;
 								invert = false;
@@ -311,14 +315,15 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 									foreground += 8;
 								}
 								bold = true;
+								foreground24 = 0;
 							}
 
-							if (seqValue == 5)
-							{
+							if (seqValue == 5) {
 								if (!workbench && options->icecolors)
 									background += 8;
 
 								blink = true;
+								background24 = 0;
 							}
 
 							if (seqValue == 7)
@@ -329,6 +334,7 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 
 							if (seqValue > 29 && seqValue < 38) {
 								foreground = seqValue - 30;
+								foreground24 = 0;
 
 								if (bold)
 									foreground += 8;
@@ -336,6 +342,7 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 
 							if (seqValue > 39 && seqValue < 48) {
 								background = seqValue - 40;
+								background24 = 0;
 
 								if (blink && options->icecolors)
 									background += 8;
@@ -387,10 +394,10 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 
 							switch (seqValue) {
 							case 0:
-								background = (color_R << 16) | (color_G << 8) | (color_B);
+								background24 = (color_R << 16) | (color_G << 8) | (color_B);
 								break;
 							case 1:
-								foreground = (color_R << 16) | (color_G << 8) | (color_B);
+								foreground24 = (color_R << 16) | (color_G << 8) | (color_B);
 								break;
 							}
 
@@ -432,10 +439,12 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 				if (invert) {
 					ansi_buffer[structIndex].background = foreground % 8;
 					ansi_buffer[structIndex].foreground = background + (foreground & 8);
-				}
-				else {
-					ansi_buffer[structIndex].background = background;
-					ansi_buffer[structIndex].foreground = foreground;
+				} else {
+					ansi_buffer[structIndex].background =
+					    background24 ? background24 : background;
+
+					ansi_buffer[structIndex].foreground =
+					    foreground24 ? foreground24 : foreground;
 				}
 				ansi_buffer[structIndex].character = current_character;
 				ansi_buffer[structIndex].column = column;
@@ -460,11 +469,10 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 		columns = fmin(columnMax, options->columns);
 
 	/* create that damn thingy */
-	if (!options->truecolor) {
+	if (!options->truecolor)
 		canvas = gdImageCreate(columns * options->bits, rowMax * fontData.height);
-	} else {
+	else
 		canvas = gdImageCreateTrueColor(columns * options->bits, rowMax * fontData.height);
-	}
 
 	if (!canvas) {
 		ctx->error = ANSILOVE_GD_ERROR;
@@ -483,19 +491,17 @@ ansilove_ansi(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	} else if (workbench) {
 		gdImageFill(canvas, 0, 0, 0);
 
-		for (int i = 0; i < 16; i++) {
+		for (int i = 0; i < 16; i++)
 			colors[i] = gdImageColorAllocate(canvas, workbench_palette[i*3],
 			    workbench_palette[i*3+1],
 			    workbench_palette[i*3+2]);
-		}
 	} else {
 		/* Allocate standard ANSi color palette */
 
-		for (int i = 0; i < 16; i++) {
+		for (int i = 0; i < 16; i++)
 			colors[i] = gdImageColorAllocate(canvas, ansi_palette[i*3],
 			    ansi_palette[i*3+1],
 			    ansi_palette[i*3+2]);
-		}
 	}
 
 	/* render ANSi */
