@@ -1,9 +1,9 @@
 /*
  * icedraw.c
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -13,12 +13,13 @@
 #include <gd.h>
 #include <stdint.h>
 #include <stdlib.h>
-#include <string.h>
 #include "ansilove.h"
 #include "drawchar.h"
 #include "output.h"
 
-#define IDF_HEADER_LENGTH 4144 /* 4096 + 48 */
+#define IDF_HEADER_LENGTH 12
+#define IDF_FONT_LENGTH 4096
+#define IDF_PALETTE_LENGTH 48
 
 int
 ansilove_icedraw(struct ansilove_ctx *ctx, struct ansilove_options *options)
@@ -30,40 +31,34 @@ ansilove_icedraw(struct ansilove_ctx *ctx, struct ansilove_options *options)
 		return -1;
 	}
 
-	if (ctx->length < IDF_HEADER_LENGTH) {
+	if (ctx->length < IDF_HEADER_LENGTH + IDF_FONT_LENGTH + IDF_PALETTE_LENGTH) {
 		ctx->error = ANSILOVE_FORMAT_ERROR;
 		return -1;
 	}
 
 	/* Get number of columns, 16-bit endian unsigned short */
-	uint32_t x2 = (ctx->buffer[9] << 8) + ctx->buffer[8];
+	uint32_t x2 = (ctx->buffer[9] << 8) + ctx->buffer[8] + 1;
 
 	/* libgd image pointers */
 	gdImagePtr canvas;
 
-	uint32_t loop = 12;
+	uint32_t loop = IDF_HEADER_LENGTH;
 	uint32_t index;
 	uint32_t colors[16];
 
 	/* process IDF */
-	uint32_t idf_sequence_length, idf_sequence_loop, i = 0;
+	uint32_t idf_sequence_length, i = 0;
 
 	/* dynamically allocated memory buffer for IDF data */
 	uint8_t *ptr, *idf_buffer;
 	idf_buffer = malloc(2);
 
-	uint16_t idf_data, idf_data_length;
-
-	while (loop < ctx->length - IDF_HEADER_LENGTH) {
-		memcpy(&idf_data, ctx->buffer+loop, 2);
-
+	while (loop < ctx->length - IDF_FONT_LENGTH - IDF_PALETTE_LENGTH) {
 		/* RLE compressed data */
-		if (idf_data == 1) {
-			memcpy(&idf_data_length, ctx->buffer+loop+2, 2);
+		if (ctx->buffer[loop] == 1) {
+			idf_sequence_length = ctx->buffer[loop+2];
 
-			idf_sequence_length = idf_data_length & 255;
-
-			for (idf_sequence_loop = 0; idf_sequence_loop < idf_sequence_length; idf_sequence_loop++)
+			while (idf_sequence_length--)
 			{
 				/* reallocate IDF buffer memory */
 				ptr = realloc(idf_buffer, i + 2);
@@ -100,7 +95,7 @@ ansilove_icedraw(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	}
 
 	/* create IDF instance */
-	canvas = gdImageCreate((x2 + 1) * 8, i / 2 / 80 * 16);
+	canvas = gdImageCreate(x2 * 8, i / 2 / 80 * 16);
 
 	/* error output */
 	if (!canvas) {
@@ -108,11 +103,10 @@ ansilove_icedraw(struct ansilove_ctx *ctx, struct ansilove_options *options)
 		free(idf_buffer);
 		return -1;
 	}
-	gdImageColorAllocate(canvas, 0, 0, 0);
 
 	/* process IDF palette */
 	for (loop = 0; loop < 16; loop++) {
-		index = (loop * 3) + ctx->length - 48;
+		index = (loop * 3) + ctx->length - IDF_PALETTE_LENGTH;
 		colors[loop] = gdImageColorAllocate(canvas,
 		    (ctx->buffer[index] << 2 | ctx->buffer[index] >> 4),
 		    (ctx->buffer[index + 1] << 2 | ctx->buffer[index + 1] >> 4),
@@ -124,7 +118,7 @@ ansilove_icedraw(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	uint32_t character, attribute, foreground, background;
 
 	for (loop = 0; loop < i; loop += 2) {
-		if (column == x2 + 1) {
+		if (column == x2) {
 			column = 0;
 			row++;
 		}
@@ -135,7 +129,7 @@ ansilove_icedraw(struct ansilove_ctx *ctx, struct ansilove_options *options)
 		background = (attribute & 240) >> 4;
 		foreground = attribute & 15;
 
-		drawchar(canvas, ctx->buffer+(ctx->length - IDF_HEADER_LENGTH),
+		drawchar(canvas, ctx->buffer+(ctx->length - IDF_FONT_LENGTH - IDF_PALETTE_LENGTH),
 		    8, 16, column, row,
 		    colors[background], colors[foreground], character);
 
