@@ -1,9 +1,9 @@
 /*
  * pcboard.c
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -13,6 +13,7 @@
 #include <gd.h>
 #include <stdint.h>
 #include <stdlib.h>
+#include <string.h>
 #include "ansilove.h"
 #include "config.h"
 #include "drawchar.h"
@@ -46,15 +47,19 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	struct fontStruct fontData;
 	size_t loop = 0, structIndex = 0;
 
+	options->columns = options->columns ? options->columns : 80;
+	uint16_t columns = options->columns;
+
 	/* font selection */
-	alSelectFont(&fontData, options->font);
+	memset(&fontData, 0, sizeof(struct fontStruct));
+	select_font(&fontData, options->font);
 
 	/* libgd image pointers */
 	gdImagePtr canvas;
 
 	uint8_t character, *cursor;
 	uint32_t background = 0, foreground = 7;
-	uint32_t column = 0, row = 0, columnMax = 0, rowMax = 0;
+	uint32_t column = 0, row = 0, rowMax = 0;
 
 	/* PCB buffer structure array definition */
 	struct pcbChar *ptr, *pcboard_buffer;
@@ -65,7 +70,7 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	while (loop < ctx->length) {
 		cursor = &ctx->buffer[loop];
 
-		if (column == 80) {
+		if (column == columns) {
 			row++;
 			column = 0;
 		}
@@ -92,20 +97,20 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 				loop += 3;
 			}
 
-			if (*cursor == 'C' && ctx->buffer[loop+2] == 'L'
-			    && ctx->buffer[loop+3] == 'S') {
+			if (!memcmp(cursor, "CLS", 3)) {
 				/* erase display */
 				column = 0;
 				row = 0;
 
-				columnMax = 0;
 				rowMax = 0;
 
+				/* reset pcboard buffer */
+				structIndex = 0;
+
 				loop += 4;
 			}
 
-			if (*cursor == 'P' && ctx->buffer[loop+2] == 'O'
-			    && ctx->buffer[loop+3] == 'S' && ctx->buffer[loop+4] == ':') {
+			if (!memcmp(cursor, "POS:", 4)) {
 				/* cursor position */
 				if (ctx->buffer[loop+6] == '@')
 				{
@@ -118,10 +123,7 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 			}
 			break;
 		default:
-			/* record number of columns and lines used */
-			if (column > columnMax)
-				columnMax = column;
-
+			/* record number of lines used */
 			if (row > rowMax)
 				rowMax = row;
 
@@ -148,11 +150,10 @@ ansilove_pcboard(struct ansilove_ctx *ctx, struct ansilove_options *options)
 
 		loop++;
 	}
-	columnMax++;
 	rowMax++;
 
 	/* allocate buffer image memory */
-	canvas = gdImageCreate(80 * options->bits, (rowMax)*fontData.height);
+	canvas = gdImageCreate(columns * options->bits, (rowMax)*fontData.height);
 
 	if (!canvas) {
 		ctx->error = ANSILOVE_GD_ERROR;
