@@ -1,9 +1,9 @@
 /*
  * tundra.c
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -51,7 +51,8 @@ ansilove_tundra(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	int16_t columns = options->columns;
 
 	/* font selection */
-	alSelectFont(&fontData, options->font);
+	memset(&fontData, 0, sizeof(struct fontStruct));
+	select_font(&fontData, options->font);
 
 	/* libgd image pointers */
 	gdImagePtr canvas;
