@@ -1,9 +1,9 @@
 /*
  * xbin.c
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -21,6 +21,7 @@
 #include "output.h"
 
 #define XBIN_HEADER_LENGTH 11 /* 4 + 1 + 2 + 2 + 1 + 1 */
+#define XBIN_PALETTE_LENGTH 48
 
 int
 ansilove_xbin(struct ansilove_ctx *ctx, struct ansilove_options *options)
@@ -69,13 +70,18 @@ ansilove_xbin(struct ansilove_ctx *ctx, struct ansilove_options *options)
 	}
 
 	uint32_t colors[16];
-	uint32_t offset = 11;
+	uint32_t offset = XBIN_HEADER_LENGTH;
 
 	/* palette */
 	if ((xbin_flags & 1) == 1) {
 		uint32_t loop;
 		uint32_t index;
 
+		if (offset + XBIN_PALETTE_LENGTH > ctx->length) {
+			ctx->error = ANSILOVE_FORMAT_ERROR;
+			return -1;
+		}
+
 		for (loop = 0; loop < 16; loop++) {
 			index = (loop * 3) + offset;
 
@@ -85,7 +91,7 @@ ansilove_xbin(struct ansilove_ctx *ctx, struct ansilove_options *options)
 			    (ctx->buffer[index + 2] << 2 | ctx->buffer[index + 2] >> 4));
 		}
 
-		offset += 48;
+		offset += XBIN_PALETTE_LENGTH;
 	} else {
 		for (int i = 0; i < 16; i++) {
 			colors[i] = gdImageColorAllocate(canvas,
