@@ -1,9 +1,9 @@
 /*
  * savefile.c
- * libansilove 1.1.5
+ * libansilove 1.2.3
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2019 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause License.
@@ -16,6 +16,8 @@
 int
 ansilove_savefile(struct ansilove_ctx *ctx, char *output)
 {
+	size_t rw;
+
 	if (ctx == NULL || output == NULL) {
 		if (ctx)
 			ctx->error = ANSILOVE_INVALID_PARAM;
@@ -25,13 +27,18 @@ ansilove_savefile(struct ansilove_ctx *ctx, char *output)
 
 	FILE *file = fopen(output, "wb");
 
-	if (file) {
-		fwrite(ctx->png.buffer, ctx->png.length, 1, file);
-		fclose(file);
-	} else {
-		ctx->error = ANSILOVE_FILE_WRITE_ERROR;
-		return -1;
-	}
+	if (!file)
+		goto err;
+
+	rw = fwrite(ctx->png.buffer, 1, ctx->png.length, file);
+	fclose(file);
+
+	if (rw != (size_t)ctx->png.length)
+		goto err;
 
 	return 0;
+
+err:
+	ctx->error = ANSILOVE_FILE_WRITE_ERROR;
+	return -1;
 }
